@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.024';
+our $VERSION = '1.026';
 
 =head1 NAME
 
@@ -543,6 +543,7 @@ sub _make_manifest {
     my ($self) = @_;
 
     my $full_manifest = $self->{full_manifest};
+    my $add_manifest  = $self->{add_manifest};
 
     my $opt      = $self->{options};
     my $par_file = $self->{par_file};
@@ -554,7 +555,7 @@ sub _make_manifest {
 
     my $manifest = join("\n",
 '    <!-- accessible as jar:file:///NAME.par!/MANIFEST in compliant browsers -->',
-        (sort keys %$full_manifest),
+        (sort keys %$full_manifest, keys %$add_manifest),
 q(    # <html><body onload="var X=document.body.innerHTML.split(/\n/);var Y='<iframe src=&quot;META.yml&quot; style=&quot;float:right;height:40%;width:40%&quot;></iframe><ul>';for(var x in X){if(!X[x].match(/^\s*#/)&&X[x].length)Y+='<li><a href=&quot;'+X[x]+'&quot;>'+X[x]+'</a>'}document.body.innerHTML=Y">)
     );
 
@@ -565,7 +566,7 @@ conflicts: {}
 dist_name: $dist_name
 distribution_type: par
 dynamic_config: 0
-generated_by: '$class version $version
+generated_by: '$class version $version'
 license: unknown
 par:
   clean: $clean
@@ -841,6 +842,9 @@ sub pack_manifest_hash {
             $full_manifest->{"script/$name"} = [ file => $in ];
             $dep_manifest->{"script/$name"}  = [ file => $in ];
         }
+
+        delete $full_manifest->{$root . "lib/$name"};
+        delete $dep_manifest->{$root . "lib/$name"};
     }
 
     my $shlib = "shlib/$Config{archname}";
@@ -1295,25 +1299,6 @@ sub _move_parl {
     $self->{fh} = $fh;
 }
 
-sub _append_parl {
-    my ($self) = @_;
-
-    my $fh = delete $self->{fh};
-
-    my $buf;
-    seek $fh, -8, 2;
-    read $fh, $buf, 8;
-    die unless $buf eq "\nPAR.pm\n";
-    seek $fh, -12, 2;
-    read $fh, $buf, 4;
-    seek $fh, -12 - unpack("N", $buf), 2;
-
-    local $/;
-    my $cfh = $self->_open('>>', $self->{parl});
-    print $cfh readline($fh);
-    close $cfh;
-}
-
 sub _generate_output {
     my ($self) = @_;
 
