@@ -241,14 +241,29 @@ my ($start_pos, $data_pos);
     open _FH, '<', $progname or last;
     binmode(_FH);
 
+    # Search for the "\nPAR.pm\n signature backward from the end of the file
     my $buf;
-    seek _FH, -8, 2;
-    read _FH, $buf, 8;
-    last unless $buf eq "\nPAR.pm\n";
+    my $size = -s $progname;
+    my $offset = 512;
+    my $idx = -1;
+    while (1)
+    {
+        $offset = $size if $offset > $size;
+        seek _FH, -$offset, 2 or die qq[seek failed on "$progname": $!];
+        my $nread = read _FH, $buf, $offset;
+        die qq[read failed on "$progname": $!] unless $nread == $offset;
+        $idx = rindex($buf, "\nPAR.pm\n");
+        last if $idx >= 0 || $offset == $size || $offset > 128 * 1024;
+        $offset *= 2;
+    }
+    last unless $idx >= 0;
 
-    seek _FH, -12, 2;
+    # Seek 4 bytes backward from the signature to get the offset of the 
+    # first embedded FILE, then seek to it
+    $offset -= $idx - 4;
+    seek _FH, -$offset, 2;
     read _FH, $buf, 4;
-    seek _FH, -12 - unpack("N", $buf), 2;
+    seek _FH, -$offset - unpack("N", $buf), 2;
     read _FH, $buf, 4;
 
     $data_pos = (tell _FH) - 4;
@@ -368,6 +383,10 @@ my ($start_pos, $data_pos);
 
     # }}}
 
+    # increase the chunk size for Archive::Zip so that it will find the EOCD
+    # even if more stuff has been appended to the .par
+    $Archive::Zip::ChunkSize = 128*1024;
+
     last unless $buf eq "PK\003\004";
     $start_pos = (tell _FH) - 4;
 }
@@ -594,9 +613,7 @@ if ($out) {
                 PAR::Filter::PodStrip->new->apply(\$content, $file)
                     if !$ENV{PAR_VERBATIM} and $name =~ /\.(?:pm|ix|al)$/i;
 
-                # Do not let XSLoader pick up auto/* from environment
-                $content =~ s/goto +retry +unless +.*/goto retry;/
-                    if lc($name) eq lc("XSLoader.pm");
+                PAR::Filter::PatchContent->new->apply(\$content, $file, $name);
             }
 
             outs(qq(Written as "$name"));
@@ -750,6 +767,8 @@ sub require_modules {
     require PAR::Heavy;
     require PAR::Dist;
     require PAR::Filter::PodStrip;
+    require PAR::Filter::PatchContent;
+    require attributes;
     eval { require Cwd };
     eval { require Win32 };
     eval { require Scalar::Util };
@@ -787,7 +806,7 @@ sub _set_par_temp {
         }
         $username =~ s/\W/_/g;
 
-        my $stmpdir = "$path$Config{_delim}par-$username";
+        my $stmpdir = "$path$Config{_delim}par-".unpack("H*", $username);
         mkdir $stmpdir, 0755;
         if (!$ENV{PAR_CLEAN} and my $mtime = (stat($progname))[9]) {
             open (my $fh, "<". $progname);
